==> ldap-account-manager_7.7.orig.tar.bz2: ldap-account-manager-7.7/templates/lib/extra/ckeditor/plugins/link/lang/lv.js <==
﻿/*
Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'lv', {
	acccessKey: 'Pieejas taustiņš',
	advanced: 'Izvērstais',
	advisoryContentType: 'Konsultatīvs satura tips',
	advisoryTitle: 'Konsultatīvs virsraksts',
	anchor: {
		toolbar: 'Ievietot/Labot iezīmi',
		menu: 'Labot iezīmi',
		title: 'Iezīmes uzstādījumi',
		name: 'Iezīmes nosaukums',
		errorName: 'Lūdzu norādiet iezīmes nosaukumu',
		remove: 'Noņemt iezīmi'
	},
	anchorId: 'Pēc elementa ID',
	anchorName: 'Pēc iezīmes nosaukuma',
	charset: 'Pievienotā resursa kodējums',
	cssClasses: 'Stilu saraksta klases',
	download: 'Piespiedu ielāde',
	displayText: 'Attēlot tekstu',
	emailAddress: 'E-pasta adrese',
	emailBody: 'Ziņojuma pamatteksts',
	emailSubject: 'Ziņojuma tēma',
	id: 'ID',
	info: 'Saites informācija',
	langCode: 'Valodas kods',
	langDir: 'Valodas lasīšanas virziens',
	langDirLTR: 'No kreisās uz labo (LTR)',
	langDirRTL: 'No labās uz kreiso (RTL)',
	menu: 'Rediģēt saiti',
	name: 'Nosaukums',
	noAnchors: '(Šajā dokumentā nav iezīmju)',
	noEmail: 'Lūdzu, ievadiet e-pasta adresi',
	noUrl: 'Lūdzu, ievadiet saites URL',
	noTel: 'Lūdzu, ievadiet tālruņa numuru',
	other: '<cits>',
	phoneNumber: 'Tālruņa numurs',
	popupDependent: 'Atkarīgs (Netscape)',
	popupFeatures: 'Uznirstošā loga nosaukums īpašības',
	popupFullScreen: 'Pilnā ekrānā (IE)',
	popupLeft: 'Kreisā koordināte',
	popupLocationBar: 'Atrašanās vietas josla',
	popupMenuBar: 'Izvēlnes josla',
	popupResizable: 'Mērogojams',
	popupScrollBars: 'Ritjoslas',
	popupStatusBar: 'Statusa josla',
	popupToolbar: 'Rīku josla',
	popupTop: 'Augšējā koordināte',
	rel: 'Relācija',
	selectAnchor: 'Izvēlēties iezīmi',
	styles: 'Stils',
	tabIndex: 'Ciļņu indekss',
	target: 'Mērķis',
	targetFrame: '<ietvars>',
	targetFrameName: 'Mērķa ietvara nosaukums',
	targetPopup: '<uznirstošā logā>',
	targetPopupName: 'Uznirstošā loga nosaukums',
	title: 'Saite',
	toAnchor: 'Iezīme šajā lapā',
	toEmail: 'E-pasts',
	toUrl: 'Adrese',
	toPhone: 'Tālrunis',
	toolbar: 'Saite',
	type: 'Saites tips',
	unlink: 'Atsaistīt',
	upload: 'Augšupielādēt'
} );

==> ldap-account-manager_8.5.orig.tar.bz2: ldap-account-manager-8.5/templates/lib/extra/ckeditor/plugins/link/lang/lv.js <==
﻿/*
Copyright (c) 2003-2023, CKSource Holding sp. z o.o. All rights reserved.
CKEditor 4 LTS ("Long Term Support") is available under the terms of the Extended Support Model.
*/
CKEDITOR.plugins.setLang( 'link', 'lv', {
	acccessKey: 'Pieejas taustiņš',
	advanced: 'Izvērstais',
	advisoryContentType: 'Konsultatīvs satura tips',
	advisoryTitle: 'Konsultatīvs virsraksts',
	anchor: {
		toolbar: 'Ievietot/Labot iezīmi',
		menu: 'Labot iezīmi',
		title: 'Iezīmes uzstādījumi',
		name: 'Iezīmes nosaukums',
		errorName: 'Lūdzu norādiet iezīmes nosaukumu',
		errorWhitespace: 'Anchor name cannot contain space characters', // MISSING
		remove: 'Noņemt iezīmi'
	},
	anchorId: 'Pēc elementa ID',
	anchorName: 'Pēc iezīmes nosaukuma',
	charset: 'Pievienotā resursa kodējums',
	cssClasses: 'Stilu saraksta klases',
	download: 'Piespiedu ielāde',
	displayText: 'Attēlot tekstu',
	emailAddress: 'E-pasta adrese',
	emailBody: 'Ziņojuma pamatteksts',
	emailSubject: 'Ziņojuma tēma',
	id: 'ID',
	info: 'Saites informācija',
	langCode: 'Valodas kods',
	langDir: 'Valodas lasīšanas virziens',
	langDirLTR: 'No kreisās uz labo (LTR)',
	langDirRTL: 'No labās uz kreiso (RTL)',
	menu: 'Rediģēt saiti',
	name: 'Nosaukums',
	noAnchors: '(Šajā dokumentā nav iezīmju)',
	noEmail: 'Lūdzu, ievadiet e-pasta adresi',
	noUrl: 'Lūdzu, ievadiet saites URL',
	noTel: 'Lūdzu, ievadiet tālruņa numuru',
	other: '<cits>',
	phoneNumber: 'Tālruņa numurs',
	popupDependent: 'Atkarīgs (Netscape)',
	popupFeatures: 'Uznirstošā loga nosaukums īpašības',
	popupFullScreen: 'Pilnā ekrānā (IE)',
	popupLeft: 'Kreisā koordināte',
	popupLocationBar: 'Atrašanās vietas josla',
	popupMenuBar: 'Izvēlnes josla',
	popupResizable: 'Mērogojams',
	popupScrollBars: 'Ritjoslas',
	popupStatusBar: 'Statusa josla',
	popupToolbar: 'Rīku josla',
	popupTop: 'Augšējā koordināte',
	rel: 'Relācija',
	selectAnchor: 'Izvēlēties iezīmi',
	styles: 'Stils',
	tabIndex: 'Ciļņu indekss',
	target: 'Mērķis',
	targetFrame: '<ietvars>',
	targetFrameName: 'Mērķa ietvara nosaukums',
	targetPopup: '<uznirstošā logā>',
	targetPopupName: 'Uznirstošā loga nosaukums',
	title: 'Saite',
	toAnchor: 'Iezīme šajā lapā',
	toEmail: 'E-pasts',
	toUrl: 'Adrese',
	toPhone: 'Tālrunis',
	toolbar: 'Saite',
	type: 'Saites tips',
	unlink: 'Atsaistīt',
	upload: 'Augšupielādēt'
} );
